# Class: pgbouncer
#
#
class pgbouncer {
    include baruwa::db
    include postgresql::server
    $pgbouncer_path = $operatingsystem ? {
        /(?i:Debian|Ubuntu)/ => "postgresql",
        default => "pgbouncer",
    }
    $pgbouncer_authfile = $operatingsystem ? {
        /(?i:Debian|Ubuntu)/ => "/var/lib/postgresql/9.1/main/global/pg_auth",
        default => "/var/lib/pgsql/data/global/pg_auth",
    }
    $pgbouncer_socketpath = $operatingsystem ? {
        /(?i:Debian|Ubuntu)/ => "/var/run/postgresql",
        default => "/tmp",
    }

    package { "pgbouncer":
        ensure => installed,
        require => Package["python-psycopg2"],
    }
    
    package { "python-psycopg2":
        ensure => installed,
    }

    service{ "pgbouncer":
        enable => true,
        ensure => running,
        hasrestart  => true,
        hasstatus   => true,
        require => [File["pgbouncer.ini"], Service["postgresql"]],
    }

    file { "pgbouncer.ini":
        path => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "/etc/pgbouncer/pgbouncer.ini",
            default => "/etc/pgbouncer.ini",
        },
        ensure  => present,
        mode    => "0644",
        owner   => "root",
        group   => "root",
        content => template("pgbouncer/pgbouncer.ini.erb"),
        require => Package["pgbouncer"],
        notify => Service["pgbouncer"],
    }

    if $operatingsystem in ['CentOS', 'RedHat'] {
        file { "/var/log/pgbouncer":
            ensure => directory,
            mode => "0750",
            owner => "postgres",
            group => "postgres",
            require => [Package["pg-server"], Package["pgbouncer"]],
            notify => Service["pgbouncer"],
        }
    }

    if $operatingsystem in ['Ubuntu', 'Debian'] {
        file { "/etc/default/pgbouncer":
            ensure  => present,
            mode    => "0644",
            owner   => "root",
            group   => "root",
            content => template("pgbouncer/pgbouncer.erb"),
            require => [Package["pgbouncer"], File["pgbouncer.ini"]],
            notify => Service["pgbouncer"],
        }
        exec { "mkauth":
            command => "/usr/lib/pgbouncer/mkauth.py /var/lib/postgresql/9.1/main/global/pg_auth 'dbname=postgres user=postgres password=$pgsql_password'",
            unless => "ls /var/lib/postgresql/9.1/main/global/pg_auth && grep baruwa /var/lib/postgresql/9.1/main/global/pg_auth",
            require => [Service["postgresql"], Postgresql::Createuser["baruwauser"]],
            notify => Service["pgbouncer"],
            user => "postgres",
        }
    }
}